==> pgadmin3-1.8.0.tar.gz: pgadmin3-1.8.0/pgadmin/include/dlg/dlgFunction.h <==
//////////////////////////////////////////////////////////////////////////
//
// pgAdmin III - PostgreSQL Tools
// RCS-ID:      $Id: dlgFunction.h 6658 2007-09-24 10:59:19Z dpage $
// Copyright (C) 2002 - 2007, The pgAdmin Development Team
// This software is released under the Artistic Licence
//
// dlgFunction.h - Function property 
//
//////////////////////////////////////////////////////////////////////////


#ifndef __DLG_FUNCTIONPROP
#define __DLG_FUNCTIONPROP

#include "dlg/dlgProperty.h"

class pgSchema;
class pgFunction;

class dlgFunction : public dlgSecurityProperty
{
public:
    dlgFunction(pgaFactory *factory, frmMain *frame, pgFunction *func, pgSchema *sch);
    int Go(bool modal);

    void CheckChange();
    wxString GetSql();
    pgObject *CreateObject(pgCollection *collection);
    pgObject *GetObject();
    void SetObject(pgObject *obj) { function = (pgFunction*)obj; }

private:
    pgSchema *schema;
    pgFunction *function;
    wxArrayString varInfo;

    void OnChangeArgName(wxCommandEvent &ev);
    void OnChangeReturn(wxCommandEvent &ev);
    void OnChangeSetof(wxCommandEvent &ev);
    void OnSelChangeLanguage(wxCommandEvent &ev);
    void OnSelChangeArg(wxListEvent &ev);
    void OnSelChangeType(wxCommandEvent &ev);
    void OnAddArg(wxCommandEvent &ev);
    void OnChangeArg(wxCommandEvent &ev);
    void OnRemoveArg(wxCommandEvent &ev);

    void OnVarAdd(wxCommandEvent &ev);
    void OnVarRemove(wxCommandEvent &ev);
    void OnVarSelChange(wxListEvent &ev);
    void OnVarnameSelChange(wxCommandEvent &ev);
    void SetupVarEditor(int var);

    wxString GetSelectedDirection();
    wxString GetArgs(const bool withNames = true, const bool inOnly = false);
    void ReplaceSizer(wxWindow *w, bool isC, int border);

	virtual bool IsUpToDate();

    wxArrayString typOids;
    wxArrayString types;
    wxArrayString argOids;

    int typeColNo;

protected:
    bool isProcedure;

    DECLARE_EVENT_TABLE()
};


class dlgProcedure : public dlgFunction
{
public:
    dlgProcedure(pgaFactory *factory, frmMain *frame, pgFunction *node, pgSchema *sch);
};


#endif

==> pgadmin3_1.8.4.orig.tar.gz: pgadmin3-1.8.4/pgadmin/include/dlg/dlgFunction.h <==
//////////////////////////////////////////////////////////////////////////
//
// pgAdmin III - PostgreSQL Tools
// RCS-ID:      $Id: dlgFunction.h 6930 2008-01-02 00:10:01Z dpage $
// Copyright (C) 2002 - 2008, The pgAdmin Development Team
// This software is released under the Artistic Licence
//
// dlgFunction.h - Function property 
//
//////////////////////////////////////////////////////////////////////////


#ifndef __DLG_FUNCTIONPROP
#define __DLG_FUNCTIONPROP

#include "dlg/dlgProperty.h"

class pgSchema;
class pgFunction;

class dlgFunction : public dlgSecurityProperty
{
public:
    dlgFunction(pgaFactory *factory, frmMain *frame, pgFunction *func, pgSchema *sch);
    int Go(bool modal);

    void CheckChange();
    wxString GetSql();
    pgObject *CreateObject(pgCollection *collection);
    pgObject *GetObject();
    void SetObject(pgObject *obj) { function = (pgFunction*)obj; }

    wxString GetHelpPage(bool forCreate) const { return wxT("pg/sql-createfunction"); }

private:
    pgSchema *schema;
    pgFunction *function;
    wxArrayString varInfo;

    void OnChangeArgName(wxCommandEvent &ev);
    void OnChangeReturn(wxCommandEvent &ev);
    void OnChangeSetof(wxCommandEvent &ev);
    void OnSelChangeLanguage(wxCommandEvent &ev);
    void OnSelChangeArg(wxListEvent &ev);
    void OnSelChangeType(wxCommandEvent &ev);
    void OnAddArg(wxCommandEvent &ev);
    void OnChangeArg(wxCommandEvent &ev);
    void OnRemoveArg(wxCommandEvent &ev);

    void OnVarAdd(wxCommandEvent &ev);
    void OnVarRemove(wxCommandEvent &ev);
    void OnVarSelChange(wxListEvent &ev);
    void OnVarnameSelChange(wxCommandEvent &ev);
    void SetupVarEditor(int var);

    wxString GetSelectedDirection();
    wxString GetArgs(const bool withNames = true, const bool inOnly = false);
    void ReplaceSizer(wxWindow *w, bool isC, int border);

	virtual bool IsUpToDate();

    wxArrayString typOids;
    wxArrayString types;
    wxArrayString argOids;

    int typeColNo;

protected:
    bool isProcedure;

    DECLARE_EVENT_TABLE()
};


class dlgProcedure : public dlgFunction
{
public:
    dlgProcedure(pgaFactory *factory, frmMain *frame, pgFunction *node, pgSchema *sch);

    wxString GetHelpPage(bool forCreate) const { return wxT("pg/sql-createprocedure"); }
};


#endif
